import { User, UserManager } from "oidc-client-ts";

// Auth User Type
export interface AuthUser extends Omit<User, "access_token"> {
  roles?: string[];
  resource_access?: {
    roles?: string[];
    [key: string]: any;
  };
  expires_at?: number;
  access_token?: string;
}

// Auth Context Type
export interface AuthContext {
  isLoading: boolean;
  isAuthenticated: boolean;
  user: AuthUser | null;
  error: Error | null;
  signinRedirect: () => Promise<void>;
  signinSilent: () => Promise<void>;
  removeUser: () => Promise<void>;
  userManager: UserManager;
  settings: any;
  events: any;
  isSignedIn: boolean;
  signinPopup: () => Promise<void>;
  signinSilentCallback: () => Promise<void>;
  signinPopupCallback: () => Promise<void>;
  signinRedirectCallback: () => Promise<void>;
  signoutRedirect: (args?: any) => Promise<void>;
  signoutRedirectCallback: () => Promise<void>;
  signoutPopup: (args?: any) => Promise<void>;
  signoutPopupCallback: () => Promise<void>;
  signoutSilent: (args?: any) => Promise<void>;
  signoutSilentCallback: () => Promise<void>;
}

// Extended Auth Context Type
export interface ExtendedAuthContext extends AuthContext {
  hasRole: (role: string) => boolean;
  getAccessToken: () => string | undefined;
  isTokenExpiringSoon: () => boolean;
  refreshToken: () => Promise<boolean>;
}
