// Initialize OpenAPI configuration
import { OpenAPI } from "./OpenAPI";
import { getApiUrlSingleton } from "@shared/lib/api-url";

// Add a global debug function for consistent logging
const debug = (message: string) => {
  console.log(`[OPENAPI-INIT] ${message}`);
};

/**
 * Initialize the OpenAPI configuration with the API URL
 */
export const initializeOpenAPI = () => {
  try {
    debug("Initializing OpenAPI configuration");

    // Get the API URL using our utility function
    const apiUrl = getApiUrlSingleton();

    // Set the OpenAPI base URL
    OpenAPI.BASE = apiUrl;
    debug(`OpenAPI initialized with BASE URL: ${OpenAPI.BASE}`);

    return true;
  } catch (error) {
    console.error("FATAL ERROR: Failed to initialize OpenAPI:", error);
    return false;
  }
};

// Add a debug statement to confirm the script is being executed
debug("initialize.ts script is being executed");

// Call initialization function
const initialized = initializeOpenAPI();

// Log initialization status
debug(`OpenAPI initialization ${initialized ? "successful" : "failed"}`);
