import React from "react";
import { Link, useLocation } from "react-router-dom";

interface NavItemProps {
  to: string;
  label: string;
  icon?: string;
  active?: boolean;
}

const NavItem: React.FC<NavItemProps> = ({ to, label, icon, active }) => {
  return (
    <Link
      to={to}
      className={`flex items-center space-x-3 px-4 py-3 rounded-md transition-colors ${
        active
          ? "bg-[#653cee] text-white"
          : "text-gray-400 hover:bg-[#3a3842] hover:text-white"
      }`}
    >
      {icon && <span className="text-lg">{icon}</span>}
      <span>{label}</span>
    </Link>
  );
};

export const Sidebar: React.FC = () => {
  const location = useLocation();
  const currentPath = location.pathname;

  const navItems = [
    { to: "/", label: "Dashboard", icon: "📊" }
  ];

  return (
    <aside className="w-64 bg-[#26242a] border-r border-[#3a3842] flex flex-col">
      <div className="p-4 border-b border-[#3a3842]">
        <h1 className="text-xl font-bold">Merchant App</h1>
      </div>

      <nav className="flex-1 p-4 space-y-1">
        {navItems.map((item) => (
          <NavItem
            key={item.to}
            to={item.to}
            label={item.label}
            icon={item.icon}
            active={
              item.to === "/"
                ? currentPath === "/"
                : currentPath.startsWith(item.to)
            }
          />
        ))}
      </nav>

      <div className="p-4 border-t border-[#3a3842] text-xs text-gray-500">
        <p>© 2023 App</p>
      </div>
    </aside>
  );
};
